## 1. Background Worldview Material

_(Attention conservation notice: general-knowledge background material included for completeness. **You may prefer to skim this section, or skip directly to §1.3 or §2.**)_

_(Epistemic status: very confident; textbook psychology and biology, and Sequences philosophy.)_

### 1.1 Sex Differences

Humans are a [sexually dimorphic](https://en.wikipedia.org/wiki/Sexual_dimorphism) species. Complex functional adapatations are [necessarily universal within a species in order to not get scrambled during meiosis](https://www.lesswrong.com/posts/Cyj6wQLW6SeF6aGLy/the-psychological-unity-of-humankind), but this sense of "universality" includes sex-specific adaptations: if the genome were a computer program, it would have `if female { /* ... */ } else if male { /* ... */ }` conditional blocks. Although rare [disorders of sex development exist](https://en.wikipedia.org/wiki/Disorders_of_sex_development), the vast supermajority of humans can be classified as unambiguously female or male.[^intersex-frequency] "Primary" sex differences of reproductive anatomy are binary (there are _no_ females who produce sperm), but most other sex differences are merely statistical ("men are taller than women" doesn't mean every man is taller than every woman) and of widely varying size: there is a quantifiable sense in which we can say that the sex difference in height ([Cohen's _d_](https://en.wikiversity.org/wiki/Cohen%27s_d) ≈ 1.5) is "five times larger" than the sex difference in verbal abilities (_d_ ≈ 0.3, favoring women).[^archer]

[^intersex-frequency]: The "classical" intersex conditions ("true hermaphrodites" who have both testicular and ovarian tissue, classical congenital adrenhal hyperplasia (CAH), and complete androgen insensitivity syndrome), have a combined frequency of 0.017%. A _much_ more generous definition of _intersex condition_ could cover as much as 1.7% of the population, the vast majority of whom have late-onset CAH. Blackless _et al._, ["How Sexually Dimorphic Are We? Review and Synthesis"](http://unremediatedgender.space/papers/blackless_et_al-how_sexually_dimorphic_are_we.pdf), cited in Charles Murray, _Human Diversity_, Appendix 2, "Sexual Dimorphism in Humans."

[^archer]: For a big list of quantified psychological sex differences, see Table 3 in John Archer, ["The Reality and Evolutionary Significance of Human Psychological Sex Differences"](http://unremediatedgender.space/papers/archer-the_reality_and_evolutionary_significance_of_human_psychological_sex_differences.pdf).

Some people think that to the extent that psychological sex differences exist, it's solely because of girls and boys being socialized differently. But this is kind of hard to square with both evolutionary theory (we see sex differences in closely related primate species,[^dunbar] even though they don't have culture the way we do) and cross-cultural regularities in sex differences in personality.[^cross]

[^dunbar]: To get an idea of how sexist the primatology literature is, consider that Robin Dunbar (of [Dunbar's number](https://en.wikipedia.org/wiki/Dunbar%27s_number) fame) actually _defines_ "personality" as "consistent styles of behavior that characterize particular individuals and mark them out as different to other individuals of the same age _and sex_" (emphasis mine). Robin I. M. Dunbar, _Primate Social Systems_, Ch. 11, "Mechanics of Exploitation."

[^cross]: Costa _et al._ 2001 "Gender Differences in Personality Traits Across Cultures: Robust and Surprising Findings", McCrae and Terracciano 2005 "Universal Features of Personality Traits form the Observer's Perspective: Data From 50 Cultures", Schmitt _et al._ 2008 "Personality and Gender Differences in Global Perspective", Mac Giolla and Kajonius 2018 "Sex Differences in Personality Are Larger in Gender Equal Countries: Replicating and Extending a Surprising Finding", cited in Charles Murray, _Human Diversity_, Ch. 2, "Sex Differences in Personality."

Some working in the broad social-construction paradigm would go so far as to claim that young children don't have genders. Depending on exactly what you mean by the word "gender", that may be so, but young children _do_ have a biological sex, which is is highly relevant to the child's _future_ development, even while babies and toddlers are not particularly sexually dimorphic. Evolutionary adaptations, including sexually-dimorphic adaptations (_e.g._, breasts) can be absent or dormant during one stage of an organism's life-cycle, only to "come online" later:[^foundations] just because a trait emerges later in developent, doesn't mean it's the result of socialization. This is most dramatically observable in the development of secondary sexual characteristics during puberty, but it does not follow that sex differences are nonexistent before puberty.

Sex differences in play styles and same-sex play groups are cross-culturally universal, with boys tending to engage in much more rough-and-tumble play with an overt focus on competition and dominance, whereas girls tend to prefer more cooperative play in smaller cliques.[^play1] [^play2]

Evidence that childhood behavioral sex differences are strongly influenced by the prenatal [organizational effects](https://en.wikipedia.org/wiki/Organizational-Activational_Hypothesis) of hormones, and not just socialization, is found in the study of girls with [cogenital adrenal hyperplasia](https://en.wikipedia.org/wiki/Congenital_adrenal_hyperplasia), who were exposed to more androgens than usual _in utero_ and have more male-typical behavior: showing, for example, [_d_ ≈ 1.5 in play activities _vs._ control girls (as compared to normal female–male sex difference of _d_ ≈ 3.3), _d_ ≈ 0.7 in interest in babies (as compared to the sex difference _d_ ≈ 1.0), and _d_ ≈ 1.1 in aggression (as compared to the sex difference _d_ ≈ 1.4)](http://unremediatedgender.space/images/cah_diffs_table.png).[^cah-play] (See also §3.3 for evidence from natal males raised as girls.)

[^cah-play]: "Prenatal Androgens and Sexual Differentiation of Behavior", Table 1, in [_Developmental Endocrinology: From Research to Clinical Practice_](http://unremediatedgender.space/papers/eugster-pescovitz-developmental_endocrinology.pdf), 

Some of dimensions of psychological sex differences may even be _more_ relevant in children than adults! Anecdotally, a lot of adults who are _ideologically_ committed to ideals of gender equality—and a lot of non-early-onset trans people—nevertheless have happy childhood memories of engaging in sex-typical play activities with groups of same-sex peers, even as their adult lives aren't gendered in that way. There's a reason the subtitle of Eleanor Maccoby's classic volume on developmental sex differences is _Growing Up Apart, Coming Together_.

[^foundations]: John Tooby and Leda Cosmides, ["The Psychological Foundations of Culture"](https://www.cep.ucsb.edu/papers/pfc92.pdf)

[^play1]: David Geary, _Male, Female: The Evolution of Human Sex Differences_, Ch. 7, "Developmental Sex Differences"

[^play2]: Anne Campbell, _A Mind of Her Own: The Evolutionary Psychology of Women_, Ch. 4, "Who Does She Think She Is? Women and Status".

### 1.2 Sex and the Cognitive Function of Categorization

Some argue that because sex differences in most traits are merely statistical, then sex differences are socially irrelevant. If you're not planning to start a family with someone (which you aren't for the vast majority of people you encounter), then their reproductive anatomy should be irrelevant to you. Of the ["Big Five" personality traits](https://en.wikipedia.org/wiki/Big_Five_personality_traits), the one with the largest sex difference is Agreeableness at _d_ ≈ 0.5,[^agreeableness] but _d_ = 0.5 isn't very big: it means that if you know someone's Agreeableness score, you can guess their sex 6 times out of 10 (rather than 5 times out of ten if you didn't have any information at all).

[^agreeableness]: Yanna J. Weisberg, Colin G. DeYoung, and Jacob B. Hirsh, ["Gender Differences in Personality across the Ten Aspects of the Big Five"](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3149680/), Table 2

This egalitarian conclusion is weakened somewhat by the observation that _many_ different traits are relevant to the sum of our interactions with a person, and [small differences in the individual traits can amount to a big difference when you consider the conjunction of many traits at once](https://www.lesswrong.com/posts/cu7YY7WdgJBs3DpmJ/the-univariate-fallacy). A good way to get an intution about this is to imagine flipping one of two collections of many biased coins, with more-biased coins representing traits with larger sex differences. (Maybe the first coin from collection A lands Heads 60% of the time, the second coin from collection A lands Heads 55% of the time, _&c._, for many different coins.) The result of any _individual_ coin flip can't tell you which collection the coin came from, but [looking at _many_ coins at once can quickly give you _godlike_ (99.9+%) confidence](http://zackmdavis.net/blog/2019/05/the-typical-set/) as to what collection you're dealing with.

This kind of multivariate analysis explains why people are very good at recognizing sex from (hair covered, males clean-shaven) photographs of people's faces (96% accuracy[^bruce]), even though you can't get that kind of accuracy with any one particular measurement (like nose height, or eye width). We don't consciously know _how_ we do it (I've read two academic papers on the topic, and I still don't really understand it), but our brains are observably good at _doing_ it anyway. A similar phenomenon likely governs social perceptions of gender: if you try to _verbally argue_ about why someone should be perceived as a particular sex, you might not come up with many persuasive verbal arguments to counter someone telling you what you _should_ perceive. But there is an natural cluster in the underlying high-dimensional configuration space that people are pretty good at sussing out in the absence of drastic medical interventions, and (tragically) often even _with_ medical interventions.

[^bruce]: Bruce _et al._, ["Sex Discrimination: How Do We Tell the Difference Between Male and Female Faces?"](http://unremediatedgender.space/papers/bruce_et_al-sex_discrimination_how_do_we_tell.pdf)

Because most sex differences in _particular_ psychological traits are small and statistical,[^hyde] one can make a strong case that restrictive gender _roles_ should be considered harmful to human flourishing. A particular boy (juvenile male human) [might happen to](http://unremediatedgender.space/2019/Jan/the-dialectic/) have many feminine traits (that is, traits that are statistically more typical of juvenile female humans)—in the coin flipping metaphor, maybe the 4th, 10th, 12th, and 17th coins came up Tails, whereas most boys' 4th, _&c._ coins come up Heads. It would be cruel and abusive to try to restrict such a child's behavior to try to manipulate him into being more male-typical: there's no "right" or "wrong" way to be a boy. If a male child wants to have long hair, or have tea parties, or repeatedly watch the film _Babies_, that's _totally fine_.

[^hyde]: Janet Shibley Hyde, ["The Gender Similarities Hypothesis"](https://pubmed.ncbi.nlm.nih.gov/16173891/)

_And yet_, given that we do _not_ yet live in a post-biological upload utopia where everyone is an androgynous being of pure information, [it seems useful to have a](http://unremediatedgender.space/2018/Apr/reply-to-the-unit-of-caring-on-adult-human-females/) [_short_ word](https://www.lesswrong.com/posts/soQX8yXLbKy7cFvy8/entropy-and-short-codes) to talk about the high-dimensional cluster of "biological sex"—to be able to name the _distribution_ that a particular sequence of coinflips came out of, even if it was a somewhat unusual draw from that distribution along some variables/dimensions. Natural categories are useful for structuring our understanding of the world even when we don't _know_ all the lower-level details: the statistical [cluster-structure](https://www.lesswrong.com/posts/WBw8dDkAWohFjWQSk/the-cluster-structure-of-thingspace) of bodies and minds in the world [is sufficiently robust](https://www.lesswrong.com/posts/yLcuygFfMfrfK8KjF/mutual-information-and-density-in-thingspace) such that we want to have words for "female" and "male", rather than being limited to only being able to say (_e.g._) "people with penises" in sentences where we can prove to a skeptical judge that penises specifically are relevant to the claim being made. Before 1905, no one knew that sex chromosomes existed, and yet, given all the other observed differences between human females and males, it would have been a _reasonable guess_ to posit some molecular mechanism of sex determination—a guess that would have turned out to be _correct_. One might speculate that it may have been more difficult to make that kind of scientific discovery in a culture that didn't have short words for biological sex categories, such that people were taught from a young age only that "some people have vulvas, but some people have penises" (rather than "women have ... men have ..."), as if genital shape were an independent trait like earlobe-attachedness that didn't particularly covary with anything else.

### 1.3 Two Possible Views on the Etiology of Gender Dysphoria in Young Children

Some humans are sad about what sex they are, and wish that they could be the other sex. We [don't really have the technology](https://www.lesswrong.com/posts/QZs4vkC7cbyjL9XA9/changing-emotions) to properly accomplish this, but we can approximate it with cross-sex hormone therapy and various surgical procedures. As a transhumanist, I think this is great! Gender transition should definitely be on the table as a possible intervention for humans who are sad about what sex they are.

_However_, smart, sane transhumanism requires _thinking carefully_ about which choices are the _best_, and which choices are the best depends on the relevant empirical facts about human psychology and the available technological interventions. _Actually_ giving people what they want [doesn't mean interpreting all of their verbal self-reports literally without questioning](http://unremediatedgender.space/2016/Sep/psychology-is-about-invalidating-peoples-identities/), because sometimes people's first guess about what they want, isn't the same as what they would want on reflection, and asking questions can help them figure it out.

In this section, I articulate two classes of _theories_ that purport to explain the majority of cases in which small children might report being, or wanting to be, the other sex. (In the next section, I'll actually argue that the case of the Blume child fits _neither_ of these putative etiologies.)

The **behavioral theory of early-onset gender dysphoria** claims that children who are far outside the typical norm of _behavior_ (_e.g._, social play styles) for their sex—very tomboyish girls and very feminine boys—[on observing the differences between themselves and their peers](https://sillyolme.wordpress.com/2009/12/28/the-origins-of-cross-gender-identity-in-transsexuals/), conclude that they are, or should be, the opposite sex. Sex-atypical childhood behavior is closely related to homosexuality as an adult. (The difference in sex-atypical childhood behavior between gay and straight adults has been meta-analyzed at _d_ ≈ 1.31 for men and _d_ ≈ 0.96 for women.[^bailey-zucker] Another study found that the correlations between measures of gender-typicality and orientation-typicality were "virtually as high as possible, given the reliability of measures".[^lippa]) In this theory, gender dysphoria _arises_ out of sex-atypical behavioral patterns that are apparent to others _before_ potentially congealing into a more stable internal "identity" that can verbally reported by the individual. Notably, a solid supermajority[^steensma] of children diagnosed with gender dysphoria end up growing out of it: in Western countries, most gender-dysphoric kids turn out to be "pre-gay", not trans. However, comparisons to other cultures suggest that the individual's ultimate social identity ends up being heavily influenced by culture: a highly masculine girl might grow up to be a butch lesbian if raised in 20th century America, or a trans man if raised in 2010s America, or a nun if raised in 17th century Europe.

[^steensma]: A "desistance" rate of 84.2% (_n_=207) is reported in Thomas D. Steensma _et al._ 2013, ["Factors Associated With Desistence and Persistence of Childhood Gender Dysphoria: A Quantitative Follow-Up Study"](http://unremediatedgender.space/papers/steensma_et_al-factors_associated_with_desistence_and_persistence.pdf)

[^bailey-zucker]: J. Michael Bailey and Kenneth Zucker, ["Childhood Sex-Typed Behavior and Sexual Orientation: A Conceptual Analysis and Quantitative Review"](http://unremediatedgender.space/papers/bailey-zucker-childhood_sex-typed_behavior_and_sexual_orientation.pdf).

[^lippa]: Richard A. Lippa, ["Gender-Related Traits in Gay Men, Lesbian Women, and Heterosexual Men and Women: The Virtual Identity of Homosexual-Heterosexual Diagnosticity and Gender Diagnosticity"](http://unremediatedgender.space/papers/lippa-gender-related_traits_in_gays.pdf)

The **gender identity theory** claims that psychological sex differences are minimal, with the exception of some innate inclination that causes them to start to identify with a social gender at around age 3. Respecting this atomic identity is very important for the child's psychological well-being, despite it not particularly relating to other variables.

I think the behavioral theory is true, and the gender identity theory is false. But if you take away nothing else from this document, I hope you will agree that the question of _which theory is true_ (including theories I haven't addressed), is highly decision-relevant in deciding how to interpret the child's self-reports. Not having a theory isn't really an option. (There's going to be an implicit theory implied by your actions, even if you haven't explicitly formulated it out loud.) As Ozy says, [truth matters](https://thingofthings.wordpress.com/2016/11/17/truth-matters/). As such, I will sometimes make _conditional_ claims later in this document. It's possible to reach agreement on the _conditional_ claim, "If the behavioral theory is true, then ...; _but_, if the identity theory is true, then ..." without yet agreeing on _which_ theory is true.

### 2.1 Introduction: the Curious Case of Clever Hans

In the early 20th century, Wilhelm von Osten, a German schoolteacher, claimed to have taught a horse, Clever Hans, to perform various intellectual feats, including complicated arithmetic, and gave public exhibitions demonstrating the animal's surprising abilities. For example, one could ask, "How much is 2/5 plus 1/2?" and the stallion would first stomp his hoof nine times, and then ten times—representing 9/10ths, the correct answer. An investigation concluded that no deliberate trickery was involved—Hans could often give the correct answer when questioned by a stranger, demonstrating that von Osten couldn't be secretly signaling the horse when to stop stomping. But further careful experiments by Oskar Pfungst revealed that Hans _was_ picking up on unconscious cues "leaked" by the questioner's body language as the number of stomps approached the correct answer. (For instance, Hans couldn't answer questions that the questioner themself didn't know.)[^pfungst]

[^pfungst]: Oskar Pfungst, [_Clever Hans (The Horse Of Mr. Von Osten): A Contribution To Experimental Animal and Human Psychology_](http://www.gutenberg.org/files/33936/33936-h/33936-h.htm), translated from the German by Carl L. Rahn

Notably, von Osten didn't accept Pfungst's explanation, continuing to believe that his intensive tutoring had succeeded in teaching the horse arithmetic. We need not question von Osten's good faith: no admission was charged at Hans's public demonstrations, so we know von Osten wasn't lying for material gain. Nor need we doubt the reports of the animal's behavior—Hans could _in fact_ stomp his hoof the number of times corresponding to the correct answer. What is in question is only the _interpretation_ of what those observations implied about Hans's psychology. As Pfungst put it: "that was looked for in the animal which should have been sought in the man."

Such _observer-expectancy effects_—where a questioner's preconceptions affect the responses of the questionee—have been demonstrated experimentally. For example, Robert Rosenthal describes a series of studies in which psychology students were instructed to administer an experiment where they ask subjects to rate whether people in photos look like they've experienced great success or failure. (Actually the photos were selected to look neutral.) The experiment-administrators were instructed to read the photo-rating task directions to the subjects verbatim and not say _anything_ else—_and yet_, administrators who were told that the expected result was more "success" or "failure" ratings, got results that were "shaded" in that direction.[^rosenthal] Even without knowing exactly _what_ subconscious cues are "leaked" from the experienter to the subject, we can measure that the effect is real. It is for this reason that psychology studies are double-blinded whenever possible.

[^rosenthal]: Robert Rosenthal, [_Experimenter Effects in Behavioral Research_](https://www.gwern.net/docs/statistics/bias/1976-rosenthal-experimenterexpectancyeffects.pdf), Ch. 9, "Human Subjects"

But _if_, as I believe, the gender-identity theory is _false_, psychological sex differences are small in toddlers, but predictably develop in older children, but beliefs about "gender" are _ordinary_ learned beliefs that toddlers can make wrong guesses about just like toddlers make wrong guesses about lots of things, then the situation looks more like—the collective sentiment of [the local social network](https://www.lesswrong.com/posts/AqbWna2S85pFTsHH4/the-intelligent-social-web) felt good about the idea of having a transgender child, so the system as a whole decided to raise this boy as a girl even though this is likely to cause problems later—_not_ as the result of anyone's conscious scheming, but just because of [everyone following their incentives](https://slatestarcodex.com/2014/07/30/meditations-on-moloch/).

Again, _which psychological theory is true_ actually matters! "Interpret all self-reports literally" might be a good _social norm_ across a wide range of circumstances (not obviously including toddlers), but it's not a psychological theory!

an instinct that might be summarized as, "Practice language and be cute to caregivers!"

kids don't choose their names; they just get acquired from socialization

Felix Fix-It Jr.

"My name is Kevin Smith Jr. now" statement as prompt to ask followup questions ("Oh, would you like me to call you _Kevin_ or _Kev Jr._, or just _Junior_?"). With enough followup questions with an sufficiently approving tone of voice, I find it entirely plausible that a name change to "Kevin Jr." would meet with the child's assent and "stick" socially. The _intitial suggestion_ would have come from the child, but most of the [optimization](https://www.lesswrong.com/posts/D7EcMhL26zFNbJ3ED/optimization)—the selection that _this particular_ one of the child's many statements should be taken literally and reinforced as a social identity, while others are just treated a cute thing the kid said

Moshe Z.'s anecdote about kid saying "I wish I were a girl" and Moshe saying "Why?" and kid giving an answer that doesn't make sense and Moshe saying, "Boys can do that, too" and kid saying "Okay"

I certainly agree that this statement from the child is some amount of evidence in favor of social transition. (It is witten that one should [update oneself incrementally](https://www.lesswrong.com/posts/627DZcvme7nLDrbZu/update-yourself-incrementally).) I expect to disagree [...] a lot about _how strong_ that evidence is, and _how strong_ the prior against is. (The base rate of early-onset taxon male-to-female transsexuals has been estimated at 3 in 100,000 male births.[^base-rate])

[^base-rate]: Kay Brown, ["FAQ on the Science of Changing Sex"](https://web.archive.org/web/20161201135826/https://sillyolme.wordpress.com/faq-on-the-science/)

This difference in priors is, again, is likely to go back to how plausible one thinks the gender-identity theory is. An _intrinsic_ preference to be thought of as a particular gender (as distinct from exhibiting sexually-typical or atypical _behavior_) just does not seem plausible to me as a feature of toddler psychology, and when interpreting a toddler's words, I think it's often correct to rely more on my model of toddler psychology than on interpreting words literally, depending on the subject matter.

If a small child says, "I like this, more!" about some food, I take that literally, because immediate sensory experieces are something any animal is qualified to have an informed preference about. If a small child _in Berkeley where people talk about gender all the time_ says, "I'm sad about being percieved as a boy", I believe the part about being sad, but I'm _much_ more skeptical about the "about being perceived as a boy" part of the description. _Taken literally_, that's a _really abstract_ preference: absent a compelling theory of where all the trans kids were ten years ago, I'm a lot more inclined to chalk it up to, "I dunno, kids say lots of weird things, including on themes they pick up from their cultural environment." (I'm not _just_ being [age-ist](https://ncc-1776.org/tle1997/le970401-10.html) here; I'm _also_ pretty skeptical of a lot of grown-up verbal self-reports of gender identity and gender dysphoria, for specific reasons that are beyond the scope of this document.)


## 3. Potential Harm Scenarios

On the other hand, if the grown-ups were to _coordinate_ with each other, "Well, the kiddo said that 'i' is called _i-dot_, and he seemed pretty insistent on it, so _that's what the letter is called now_," and go on to consistently call "i" _i-dot_, then however benevolent their intent was, I claim that this would not be in the child's long-term interests: the momentary disappointment today of having been wrong about the name of a letter, is better than the much larger disappointment and _confusion_ of finding out—potentially years later—that that's not actually what the letter is called.

In the case of having been misled about how to pronounce a letter of the alphabet, the resulting confusion and practical disadvantage would be pretty small. Letter names are just a convention: Americans say _zee_ where people from Canada and the UK say _zed_, and the difference doesn't cause a whole lot of problems.

But if we imagine a child being systematically misled about something more functionally substantive, and less a matter of arbitrary convention, the resulting problems and confusion would be correspondingly greater.

Suppose a small child were to assert that the symbol "9" is a "six". It _is_ the same symbol as "6", just upside down—a good observation and a logical guess on the child's part, just as it was good observation and a logical guess on [the child's] part to think (at first) that _l_ is "ai" and _i_ is "i-dot".

But if the grown-ups were to _coordinate behind the child's back_ that "9" is now a "six" in this house, because the child said so and seemed pretty insistent about it at the time (and who can say what kind of emotional harm might be inflicted on the child by denying the claim?), that would be bad for the child's long-term interests in a _deeper_ way than just changing a letter name. As Americans and Canadians working together have found, the English alphabet is still perfectly usable if you call _z_ "zed" (or _i_ "i-dot"). In contrast, if "9" and "6" are the same thing, then _arithmetic doesn't work_. 

But _at the time_ of initially identifying "9" as a six, the child has no way of knowing that this is a mistake that makes arithmetic impossible. In the _initial_ phases of learning to count—counting as reciting a sequence, without yet having mastered the idea of numbers as abstracting over sizes of collections—the child might not notice anything wrong with the _sequence of sounds_ "six, seven, eight, six". [(As the author of the popular _Slate Star Codex_ blog notes, machine-learning models like GPT-2 don't notice, either.)](https://slatestarcodex.com/2019/02/19/gpt-2-as-step-toward-general-intelligence/) But that sequence _is_ wrong, if you want to bootstrap from reciting the sequence of sounds to _using numbers to make sense of the world_. The _symbols_ involved in the equation "6 + 3 = 9" are all social constructs, but the reason those specific social constructs _work_ is because ●●●●●●-and-●●● is as many as ●●●●●●●●● as a culture-independent fact of nature, and we _represent_ this fact [using a convention that maps](https://www.lesswrong.com/posts/4hLcbXaqudM9wSeor/philosophy-in-the-darkest-timeline-basics-of-the-evolution) ●●●●●●-many to the symbol "6" and ●●●●●●●●●-many to the symbol "9".

Obviously, this example of indefinitely going along with a child's claim that "9" is a six is a whimsical hypothetical thought experiment. But I think this thought experiment does _illustrate_ the more general claim that going along with a small child's concept-guesses is not always in the child's long-term best interests, and I hope you will grant the _possibility_ that this claim _could_ apply in more complicated cases, like that of a child gender transition. (Of course, making that case will require more argumentation and cannot be established merely [by analogy](https://www.lesswrong.com/posts/C4EjbrvG3PvZzizZb/failure-by-analogy).)

### 3.2 Harms from Illegible Miscategorization

An adherent of the gender-identity theory might argue that it can't possibly harm [...] to call her a girl, because if being socially recognized as a girl were hurting her, she would just say so. (And she hasn't said so.)

I have no doubt that if the child were to clearly and distinctly insist, "I'm definitely a boy; please call me [...] and refer to me with he/him pronouns," then everyone would respect that.

But the harm I'm theorizing is _not_ that the child has an intrinsic male identity that hurts to not be respected; on my theory, there _is no_ "identity" apart from the _ordinary_ factual belief that one is of a particular sex.

Rather, the concern is that social transition prompts everyone, _including the child themself_, to use their mental models of girls (juvenile female humans) to make (mostly subconscious rather than deliberative) predictions and decisions about the child, which will be a systematically worse statistical fit than their models of boys (juvenile male humans), because the child is, _in fact_, a boy (juvenile male human), and those miscalibrated predictions and decisions will make the child's life worse in a complicated, illegible way that _doesn't_ necessarily result in the child spontaneously verbally asserting, "I prefer that you call me a boy."

If the child ends up having life problems that are _in fact_ the result of social transition having been a bad idea, _how is he supposed to figure that out_, when all the grown-ups in his life have agreed that he's a girl since he was three years old, _and_ are colluding to hide evidence that he's male from him on the _assumption_ (derived from something like the gender-identity theory) that such information would hurt him?

The author of the popular _Slate Star Codex_ blog writes that [concept-shaped holes can be impossible to notice](https://slatestarcodex.com/2017/11/07/concept-shaped-holes-can-be-impossible-to-notice/):

> I went years without realizing I didn't have any emotions. I was getting treated for obsessive-compulsive disorder with high dose SSRIs. When these work well they dull your depression and anxiety; when they work less well, they dull all your emotions. For me they worked less well, but I never realized it until I came off them after five years and was suddenly overwhelmed by emotions I'd almost forgotten it was possible to have. In the interim, I'd understood that getting a birthday present was a positive and desirable event, and said it made me "happy", without realizing something was missing. This was particularly inexcusable since I'd felt the full range of emotions before I started the drugs, but I guess the hypothesis "I have stopped feeling emotions" is a hard one to consider and collect evidence for.

Similarly, the hypothesis "I'm having a systematically worse childhood than I otherwise would have because all the grown-ups in my life have agreed I was a girl since I was three years old, even though all of my actual traits are sampled from the joint distribution of juvenile male humans, not juvenile female humans" might be a hard one for [a child] to consider and collect evidence for, even if it's true.

So far, this section has been rather theoretical and abstract—with reason, because my concern largely _is_ grounded in theoretical concerns (rather than having seen a lot of kids being raised as trans on the basis of the gender-identity theory and _observing_ things going wrong—although see §3.3 for what I think we can learn from the literature). Still, the skeptical reader would do well to demand: okay, what would be a _specific example_ of bad "predictions and decisions" [...]

As a hypothetical example of the _class_ of thing I'm worried about—that is, I'm not claiming that the [burdensome details](https://www.lesswrong.com/posts/Yq6aA4M3JKWaQepPJ/burdensome-details) of _specific_ scenario will happen, just trying to illustrate the _kind_ of thing that might happen—I could easily imagine a scenario where [child] really-really wants to play with a group of boys at the neighborhood playground who are roughhousing in the sand, but they reject her on the grounds that girls have cooties and can't roughhouse. Then [child] tries to play with a group of other girls (she really wanted to roughhouse, but playing with this group of other girls is better than not getting to play with anyone), but they reject her for being "a boy." (Even if [child] is wearing a dress, and objects, "No, I'm a girl!", the other girls' brains may have successfully detected a boy-typical high-dimensional regularity in [child] behavior, even if they can't articulate the low-level features that their brains are using to perform that categorization. Their rejection would be no less painful for poor [child], even if the girls would have _also_ used the same language to reject a female child who behaved the same way.[^early-onset]) [child] comes home crying and doesn't make any friends at the playground.

[^early-onset]: And according to the behavioral theory of early-onset gender dysphoria, this kind of thing happening to a female child is where trans boys come from.

If something like this were to happen, I'm worried that adults at Valinor might conceptualize the problem strictly as one of "some of those kids at the playground are _bullies_, and Society is still sexist." It may very well be _true_ that some of those kids at the playground are bullies, and that Society is still sexist. (If I were a benevolent central social planner who _knew how_ to eradicate the "girls have cooties" meme at acceptable cost, I would do so.)

[in the counterfactual that we can't observe, maybe] would have just roughhoused with the boys in the sand and made friends, and that outcome would have been _better for the child_.

This is, again, a hypothetical scenario—we haven't _observed_ [...] and in the world where we did, we wouldn't be able to observe whether or not similar social difficulties _would_ have occured in the counterfactual world where [the child] never transitioned. But I think this is representative example of the _class_ of thing that's likely to go wrong when you raise a biologically male child as a girl, and I think there are likely to be many others that I don't know how to anticipate in detail, because I [don't have introspective access to a pre-enumerated list](http://unremediatedgender.space/2019/Dec/more-schelling/) of every situation in which people's brains use gender categories to make a prediction or decision.

I think it's important that [parents] have "an implicit expectation mismatch between the male and female trait distributions is making [child's] life worse" as a _live hypothesis_, that [child] might not spontaneously invent if the grown-ups in her life are (with the most benevolent of intentions) deliberately concealing evidence from her about sex differences and about her being male.

Whereas—as ideologically uncomfortable as it may be to say it so baldly—I think the child liking trucks _is_ evidence that the child's psychology is within the male normal range: a recent meta-analysis of 75 papers found that the sex difference in child preference for vehicle toys was _d_ ≈ 2.44, and that "gender effects on children's toy preferences have remained generally constant in magnitude across the past five decades".[^truck-d] Which in turn is evidence that social transition will turn out to not be in the child's long-term best interests, even if there aren't _immediately visible_ problems.

[^truck-d]: Jac T. M. Davis and Melissa Hines, ["How Large Are Gender Differences in Toy Preferences? A Systematic Review and Meta-Analysis of Toy Preference Research"](http://unremediatedgender.space/papers/davis-hines-how_large_are_gender_differences_in_toy_preferences.pdf).

I have some misgivings that so many of my attempts to discuss trans issues end up focusing on psychological sex differences. I think this happens because physiological differences tend not to be what is in dispute: no one _disagrees_ that trans men have uteruses unless they get a hysterectomy, whereas my skepticism about gender-identity theories is at least something to talk about. But I worry that this focus tends to create misunderstandings: for example, Ozy (unintentionally) mischaracterizes me as ["argu[ing] for the existence of a third definition, based on psychology"](https://thingofthings.wordpress.com/2018/06/18/man-should-allocate-some-more-categories/). But I'm not trying to _define_ "gender" in terms of psychology: rather, I want ordinary common-sense language to talk about the ordinary common-sense category of biological sex, which I think people still need in order to make sense of the world, even if "ordinary common-sense" turns out to not be _algorithmically_ simple, because it turns out that our brains are good at representing high-dimensional statistical regularities that make discrete or effectively-discrete (say _d_ >> 3) predictions about some things (like the presence of uteruses) _and_ very weak (say _d_ ≈ 0.2) statistical predictions about other things (like particular psychological traits), such that [_no_ simple definition contains all the information conveyed by category-membership](https://www.lesswrong.com/posts/i2dfY65JciebF3CAo/empty-labels), and yet we still [aren't tempted to consider a plucked chicken as a human even if we previously offered "featherless biped" as a candidate definition of _human_](https://www.lesswrong.com/posts/jMTbQj9XB5ah2maup/similarity-clusters).

But the discrete (or large effect-size) predictions made by sex categories are still useful _sometimes_, even if they're not relevant in _every_ particular interaction with every particular person. In the course of a verbal debate, it's easy to _claim_, and fail to immediately notice anything wrong with the claim, that short words like "woman"/"man"/"girl"/"boy" are strictly _social_ categories, such that there's nothing misleading or confusing about saying that [child] is a girl because she said she was a girl, and everyone agrees that she's a girl. But I don't think this stance is actually consistent with how people's brains use and process language in the real world.

An arbitrarily-chosen example: Sarah Constantin reports, "TIL: a boy's balls are sensitive before puberty too!!!"[^balls] In this sentence, Sarah is mentioning a fact she just learned about juvenile male humans, that she didn't know and could not have known from personal experience, but which came up in the course of parenting of juvenile male human. The word _boy_ in that sentence _refers to_ an _empirical_ regularity in the physical world, a regularity that _includes_ [trans mtf children] You know _exactly_ what Sarah meant by that sentence; someone who objected, "I'm confused—not all boys have balls. Did you mean a.m.a.b.?" would be _rightfully_ written off as a troll. The purpose of this document is that I think the child [...] _also deserves to know_, and probably _doesn't_ know if all the grown-ups in the child's life are insistent on affirming that, for example, "when you were little you couldn't talk so [your parents] just had to guess [whether you were a boy] based on your parts"—implying that the guess was _wrong_. But it _wasn't_ wrong _with respect to_ the sense of the word "boy" that Sarah is using, which is still a pretty central and indispensible use of the word, even if words can be used with different meanings depending on context.

[^balls]: [#today-i-learned, "Sarah's Corner" Discord server, 29 April 2020](https://discordapp.com/channels/690246600789983320/690252795093581892/705223911981449334)

But the WHO actually publishes _two different_ growth charts: one for girls, and one for boys. ([Including](https://www.cdc.gov/growthcharts/data/who/GrChrt_Boys_24HdCirc-L4W_rev90910.pdf) [separate](https://www.cdc.gov/growthcharts/data/who/GrChrt_Girls_24HdCirc-L4W_9210.pdf) head-circumference-for-age and weight-for-length charts for babies and toddlers up to 24 months.)


I imagine that someone who is deeply committed to the gender-is-strictly-a-social-category position will not be particularly impressed by a couple of arbitrarily-chosen examples where people naturally use words like "boy" and "girl" to refer to sex-as-biological-category, because any _particular_ such instance can be dismissed as a little thing that's "not really important". (One could hypothetically argue, "Those growth chart curves are _pretty similar_—the WHO is being sexist by publishing separate charts rather than having one chart where the percentile curves are with respect to the population of all kiddos!")

But I think life is _made of_ hundreds or thousands of these little details that are deceptively easily to handwave as unimportant _when examined individually_, but are hugely significant in aggregate.

The conceptual distortions demanded by gender-identity ideology are [easy to doublethink around](http://unremediatedgender.space/2020/Apr/peering-through-reverent-fingers/) as a grown-up who (a) knows that biological sex exists, but also, separately, (b) has internalized the _highly context-specific_ taboos around _making explicit reference_ to sex in situations where that could be construed to invalidate trans people. But I don't think a small child is occupying the same epistemic state, and I think he would _need_ to occupy that state in order to be able to give informed consent to transition.

 has a perfectionist streak: he's anxious about doing things that he doesn't yet know how to do well. Given this context, it would be cruel to set up the expectation that he can do something that, _in fact_, he _physically cannot_ do well. And _with respect to_ the _primary_ "juvenile female human" definition of the word _girl_, he _can't_. (Notwithstanding that the word _girl_ can also be given a trans-inclusive definition in many or most contexts.)

**[TODO: _contradiction_ might be distressing to the child—like it might be distressing to be told that "9" isn't a "six", if you've spent the last two years believing otherwise—but it would be really bad if the pain of grappling with that contradiction were intepreted by the grown-ups as more "gender dysphoria" for which the treatment is to suppress information _even more_—when the child counterfactually would have been just fine if the grown-ups two years ago had just said, "No, that's a nine"]**

### 3.3 Evidence From the Cloacal Extrophy Literature

> _If you need to mail a baby but you're worried it'll die  
> Start a search and learn from others who have given it a try_
>
> —AVByte, ["Google Is Your Friend"](https://www.youtube.com/watch?v=ftQ6A3DKKeg)

_(Epistemic status: lit review)_

[TODO: summarize Reiner's ["Psychosexual development in genetic males assigned female: the cloacal exstrophy experience"](http://unremediatedgender.space/papers/reiner-psychosexual_development_in_genetic_males.pdf) and the discussion of Reiner's work in Ch. 3 of [_The Man Who Would Be Queen_](https://surveyanon.files.wordpress.com/2017/09/the-man-who-would-be-queen.pdf); basically, it used to be standard practice for boys with a penis-destroying rare birth defect to be raised as girls; it didn't take about half the time, and kids for whom it did take are not obviously happy]

### 3.4 Switching Costs Are Not Obviously Trivial

[TODO: people say this is costless because if it turns out [child] decides she's actually a boy, she can just say that. I don't think it's that simple: programmers know that refactoring a codebase is not free; and changing the way you think and refer to someone is also not free]

[TODO: §A.1 for a personal story about switching costs]

### 3.5 Costs of Medical Interventions

_(Epistemic status: relying more on theory rather than having mastered the literature than I would like)_

[TODO: by transitioning a kid now, you're committing to _either_ paying the switching costs of detransition, or going for medicalization. "Bioidentical" HRT is probably "reasonably" safe (I mean, all of our friends are doing it), but the "puberty blockers are fully reversible and have no side effects" cheerleading looks incredibly dubious]

[TODO: actually learn the literature here]

### 3.6. On the Scope and Extent of Biodeterminism

[TODO: in Discord, S.A. argues that there's no point in worrying about what's happening now because you can't "make" a kid trans, as shown by the behavioral genetics literature saying that parenting doesn't matter, and the [David Reimer](https://en.wikipedia.org/wiki/David_Reimer) case. My replies: first, the behavioral genetics literature actually doesn't say "parenting doesn't matter": what it says is that the shared-environment component _C_ in the [_ACE_ model](https://en.wikipedia.org/wiki/ACE_model) is near zero _specifically for personality and adult intelligence_. I agree with the behavioral genetics literature that the grown-ups can't shape [the child's] _personality_. The worry is more that "transgender" _identification_ is more like a religion than a personality as far as mechanisms of transmission go. Thus ["We don't have a gender gap, we just have an assigned sex at birth gap"](https://thingofthings.wordpress.com/2014/12/01/lw-has-an-assigned-sex-at-birth-gap-not-a-gender-gap/). (The _ACE_ model results show that _degree_ of religiosity is highly heritable, but _which_ religion is an entirely cultural matter.) Things that undergo huge changes in a short time period can't be genetic, but we've _seen_ enormous numbers of people self-IDing as trans that weren't a decade ago. (This is also why Flynn effect gains are "hollow": the meaning of an IQ test can vary over time as different cohorts live in different environments, but variance in IQ scores within the same cohort is highly heritable.) The underlying psychological variations that make trans seem like a good idea (e.g. autogynephilia) are heritable, but that does _not_ mean "born this way." (Previous generations of lesbian trans women were just crossdressers, and it's not obvious that that wasn't better for most of them.) You probably don't want to cite Reimer as a "nothing to worry about" story (because raising him as a girl didn't take) given that he committed suicide.]

## Appendix A. Some Personal Anecdotes and Reflections

_(Epistemic status: autobiographical recollections and personal value judgements.)_

_(Relevance status: as a male, and a male whom no one seems to dispute has some transgender predispositions, it's not implausible that reflections on gender-related aspects of my own childhood is somewhat-relevant data for making probabilistic-inferences-by-analogy to [...] likely development. For the same reason, I would recommend asking some of the trans women we know about their childhoods.)_

Two toys I fondly remember having as a very small child were [Polly Pocket](https://en.wikipedia.org/wiki/Polly_Pocket), and a pink-and-purple girls' scooter with hearts on it. I remember the Polly Pocket locket case being a [magenta heart](http://unremediatedgender.space/images/polly_pocket_case.jpg), and the [tiny Polly figurine was wearing a red dress](http://unremediatedgender.space/images/polly_pocket.jpg). (Link images scraped from Google Image Search, but they match my memories.) I'm glad that I had nice '90s-liberal parents who got me the toys I wanted, rather than mean conservative parents who police their kiddo's toy choices. Kiddos of either sex should be able to play with whatever toys they want!

I don't particularly remember what it was like to be three. I find it _entirely plausible_ that if I had been raised in a similar cultural environment as the one [...] is growing up in, that I might have been judged to be trans on similar evidence. (We didn't have video games in my household, but "Zack wanted Polly Pocket" seems roughly analogous to "[..] chooses female video game characters", 

I didn't have a particularly happy childhood. I was kind of a crybaby. (Still am.) But I think my caretakers expecting me to be a girl who just happened to have a penis would have made things _so much worse_. Because, you know ... I was, _in fact_, a boy (juvenile male human) and I _fit into the world_ as a boy. Certainly _not_ a prototypically-masculine male. But sensitive, bookish boys who happen to like Polly Pocket (among many other toys) are still ... boys? Systematically lying to me about what sex I am would not have been helping me?

_On the other hand_, when I started having transgender feelings as a teenager, I _do_ wish I had had more information about transitioning (undertaking interventions to phenotypically resemble the opposite sex and live socially as one) possibly being an option for males who were having the kinds of thoughts and feelings I was having at the time. (And specifically, I wish I had information that actually went into the details of giving a plausible _account_ for the kinds of thoughts and feelings I was having at the time, rather than "If you want to be a girl, you can just be a girl", which is circular and doesn't explain anything.)

As we've seen from many of our friends, MtF transitions in the teens or twenties can work out rather well. And as a fourteen- or sixteen- or twenty-year-old who knows what sex is, who can read and reason, I could have been in a position to maybe go down that path with Actually Informed consent. But the underlying _psychology_ of me wanting to be a girl at age 14–32, and me at age 3, were _very different_ and need to be reasoned about separately. If you _first_ understand the nature of the underlying psychological condition, _then_ you can make an intelligent decision on what to do about it.

[TODO: talk about how grownups exert power over the default with the example that my Dad used to say "Okay, let's go get a haircut", and it wasn't until I was 20 that I realized that I might want my hair long (for gender-related reasons)]

[TODO: talk about that time when I was maybe six and I asked whether boys could get married because I wanted to marry my friend Jon. In today's environment, that could be spun as me being gay/queer and that this identity needs to be celebrated ... but the actually I was just a confused six-year-old, and the grown-ups in Walnut Creek 1994 were sensible enough not to overinterpret my self-report.]

### A.1. The Story About My Name

[TODO: tell the story about how I tried using "Z.M." as if it were a first name because I wanted a gender-neutral byline (never mind that "Zachary" is an order of magnitude more common than "Zoë" and "Zelda" put together; I didn't really think it through) and I wanted my byline to be the same as what people called me in real life, but it didn't "stick", in part because "Z. M." doesn't feel like a name, and in part because a lot of people were still trained on calling me Zack, and the whole affair was really traumatizing for me. Moral: switching costs are not trivial—not having to pay the mundane, practical costs turned out to be _far more important_ to me-as-a-whole-person than my conscious verbal ideological whim of "It would be cool to have a gender-neutral name".]


----

Apparently, it's not hard for subtle social incentives to nudge an ordinary male child into self-reporting "I'm a girl", not because of any underlying trans disposition, but for the lack of information to determine an answer on the basis of anything other than subtle social incentives: if no one can say, "You're a boy because boys are the ones with penises" (because that's not what people in Berkeley are supposed to believe in 2020), it's not obvious how the child is supposed to figure that out independently.
